#!/usr/bin/env python
# -*- coding: utf-8 -*-

def set_trace():
    '''
    Set a tracepoint in the Python debugger that works with Qt
    Taken from:
    http://stackoverflow.com/questions/1736015/debugging-a-pyqt4-app
    '''
    from PyQt4.QtCore import pyqtRemoveInputHook
    try:
        import ipdb as pdb
    except ImportError:
	import pdb
    pyqtRemoveInputHook()
    pdb.set_trace()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

with open('README') as readme:
    __doc__ = readme.read()

from setuptools import setup

setup(
    name='pdb4qt',
    version='0.1',
    description=u'A set_trace() that works with PyQt4',
    long_description=__doc__,
    author = u'Martín Gaitán',
    author_email = 'gaitan@gmail.com',
    url='https://github.com/nqnwebs/pdb4qt',
    packages=['pdb4qt'],
    classifiers = [
        'Development Status :: 4 - Beta',
        'Environment :: X11 Applications :: Qt',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Desktop Environment',
      ]
)
